@@ -19,6 +19,7 @@ import gtk
 import gobject
 import os
 import hashlib
+import binascii
 from urlparse import urlparse
 from io import BytesIO
 import shutil
@@ -198,18 +199,17 @@ class Base(object):
         key = ''
         iv = ''
         encrypted = False
-        if len(urlparts.fragment):
-            fragment = []
-            try:
-                for i in range(0, len(urlparts.fragment), 2):
-                    fragment.append(chr(int(urlparts.fragment[i:i + 2], 16)))
-                fragment = ''.join(fragment)
-                key = fragment[16:]
-                iv = fragment[:16]
-                if len(key) == 32 and len(iv) == 16:
+        if urlparts.fragment:
+            fragment = binascii.unhexlify(urlparts.fragment)
+            key = fragment[16:]
+            iv = fragment[:16]
+            if len(key) == 32 and len(iv) == 16:
+                encrypted = True
+            if not encrypted:
+                key = fragment[12:]
+                iv = fragment[:12]
+                if len(key) == 32 and len(iv) == 12:
                     encrypted = True
-            except:
-                pass
 
         # file exists but thumbnail got deleted
         if os.path.exists(filepath) and not os.path.exists(thumbpath):
